﻿using System.IO;
using System.Reflection;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace HelloWorld
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            var proj4 = new Proj4Projection
            {
                InternalProjectionParametersString = Proj4Projection.GetWgs84ParametersString(),
                ExternalProjectionParametersString = Proj4Projection.GetSphericalMercatorParametersString()
            };

            var location = Directory.GetParent(Directory.GetParent(Directory.GetParent(Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location)).FullName).FullName).FullName;

            var weatherLocation = Path.Combine(location, "Images");

            GdiPlusRasterLayer radarImageLayer = new GdiPlusRasterLayer(Path.Combine(weatherLocation,@"latest_RadarOnly_filtered.gif"),
                Path.Combine(weatherLocation, @"latest_radaronly.gfw"))
            {
                UpperThreshold = double.MaxValue,
                LowerThreshold = 0,
                ImageSource = {Projection = proj4}
            };


            wpfMap1.MapUnit = GeographyUnit.Meter;

            var worldMapKitRoadOverlay = new WorldMapKitWmsWpfOverlay {Projection = WorldMapKitProjection.SphericalMercator};
            wpfMap1.Overlays.Add(worldMapKitRoadOverlay);

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add(radarImageLayer);
            wpfMap1.Overlays.Add(overlay);
            

            radarImageLayer.Open();
            wpfMap1.CurrentExtent = radarImageLayer.GetBoundingBox();

            wpfMap1.Refresh();

        }

//        private void Window_Loaded(object sender, RoutedEventArgs e)
//        {
//            var fontFam = new FontFamily(new Uri("pack://application:,,,/"), "./resources/#Falcon, Verdana");
//            var face = new Typeface(fontFam, FontStyles.Normal, FontWeights.Normal, FontStretches.Normal);

//            string cacheFolder = Path.Combine(Path.GetTempPath(), "TileCache");

//            wpfMap1.MapUnit = GeographyUnit.Meter;

//            var timer = new Timer {Interval = 1000};
//            timer.Elapsed += timer_Elapsed;
//            //timer.Enabled = true;
//            _startTime = DateTime.Now;
//            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"../../AppData/Countries02.shp");
//            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
//            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            

//            ShapeFileFeatureLayer capitalLayer = new ShapeFileFeatureLayer(@"../../AppData/WorldCapitals.shp");
//            // We can customize our own Style. Here we passed in a color and a size.
//            capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.White, 7, GeoColor.StandardColors.Brown);
//            // The Style we set here is available from ZoomLevel01 to ZoomLevel05. That means if we zoom in a bit more, the appearance we set here will not be visible anymore.
//            capitalLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;

//            capitalLayer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.Capital3;
//            // The Style we set here is available from ZoomLevel06 to ZoomLevel20. That means if we zoom out a bit more, the appearance we set here will not be visible any more.
//            capitalLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

//            ShapeFileFeatureLayer capitalLabelLayer = new ShapeFileFeatureLayer(@"../../AppData/WorldCapitals.shp");
//            // We can customize our own TextStyle. Here we passed in the font, the size, the style and the color.
//            capitalLabelLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("CITY_NAME", "Arial", 8, DrawingFontStyles.Italic, GeoColor.StandardColors.Black, 3, 3);
//            // The TextStyle we set here is available from ZoomLevel01 to ZoomLevel05.
//            capitalLabelLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;

//            capitalLabelLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle = TextStyles.Capital3("CITY_NAME");
//            // The TextStyle we set here is available from ZoomLevel06 to ZoomLevel20.
//            capitalLabelLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
//            capitalLabelLayer.DrawingMarginPercentage = 50;
//            var rotate = new RotationProjection();
////            ShapeFileFeatureLayer.BuildIndexFile(@"C:\Temp\MKC_MAP_60_NM_04-28-10.shp");
//           // ShapeFileFeatureLayer shapeLayer = new ShapeFileFeatureLayer(@"C:\Temp\MKC_MAP_60_NM_04-28-10.shp");
//            var shapeLocation = @"C:\Users\Kevin.IWS.000\AppData\Local\Temp\Falcon32015\SavedMaps\55697\55697.shp";
//            ShapeFileFeatureLayer.BuildIndexFile(shapeLocation, BuildIndexMode.Rebuild);
//            ShapeFileFeatureLayer shapeLayer = new ShapeFileFeatureLayer(shapeLocation);
//            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle =  new LineStyle(new GeoPen(GeoBrushes.PastelYellow));
//            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoPen(GeoBrushes.PastelYellow));

//            wpfMap1.ExtentOverlay.LeftClickDragMode = MapLeftClickDragMode.Disabled;
//            wpfMap1.ExtentOverlay.LeftClickDragKey = Keys.A;
//            wpfMap1.DragLeave +=wpfMap1_DragLeave;

//            var prjString = File.ReadAllText(Path.Combine(Path.GetDirectoryName(shapeLocation),
//                Path.GetFileNameWithoutExtension(shapeLocation) + ".prj"));

//           // var geogUnit = Proj4Projection.GetGeographyUnitFromPrj(prjString);

//            var proj4 = new Proj4Projection
//            {
//                InternalProjectionParametersString = Proj4Projection.GetWgs84ParametersString(),
//                ExternalProjectionParametersString = Proj4Projection.GetSphericalMercatorParametersString()
//            };

//            var radarImageLayer = new GdiPlusRasterLayer(@"C:\Temp\FalconData\Weather\Latest_RadarOnly_filtered.gif", @"c:\Temp\FalconData\Weather\latest_radaronly.gfw")
//            {
//                UpperThreshold = double.MaxValue,
//                LowerThreshold = 0,
//                ImageSource = {Projection = proj4},
//            };

//            if (!File.Exists(@"C:\Users\Kevin.IWS.000\AppData\Local\Temp\Falcon32015\SavedMaps\55697\55697-merc.shp"))
//            {
//                ShapeFileFeatureLayer.SaveToProjection(shapeLocation, @"C:\Users\Kevin.IWS.000\AppData\Local\Temp\Falcon32015\SavedMaps\55697\55697-merc.shp", proj4, OverwriteMode.Overwrite);
//                shapeLayer.FeatureSource.Projection = proj4;    
//            }
            
//            shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
//            //wpfMap1.CurrentScale = 1126;
//            //shapeLayer.FeatureSource.Projection = rotate;

////            WorldMapKitWmsWpfOverlay worldMapKitRoadOverlay = new WorldMapKitWmsWpfOverlay();
////            worldMapKitRoadOverlay.Name = "World Map Kit Road";
////            worldMapKitRoadOverlay.TileHeight = 512;
////            worldMapKitRoadOverlay.TileWidth = 512;
////            worldMapKitRoadOverlay.Projection = WorldMapKitProjection.SphericalMercator;
////            worldMapKitRoadOverlay.MapType = WorldMapKitMapType.Road;
////            worldMapKitRoadOverlay.IsVisible = true;
////            worldMapKitRoadOverlay.TileCache = new FileBitmapTileCache(cacheFolder, "World Map Kit Road");
////            OpenStreetMapOverlay openStreetMapOverlay = new OpenStreetMapOverlay();
////            openStreetMapOverlay.Name = "Open Street Map";
////            openStreetMapOverlay.TileHeight = 512;
////            openStreetMapOverlay.TileWidth = 512;
////            //openStreetMapOverlay.IsVisible = true;
////            openStreetMapOverlay.TileCache = new FileBitmapTileCache(cacheFolder, "OpenStreetMap");
////            wpfMap1.Overlays.Add("OpenStreetMap", openStreetMapOverlay);
////           wpfMap1.Overlays.Add(openStreetMapOverlay);
//           // openStreetMapOverlay.IsVisible = true;

//            WorldMapKitWmsWpfOverlay worldMapKitOverlay = new WorldMapKitWmsWpfOverlay();
//            //worldMapKitOverlay.
//            //worldMapKitOverlay.Projection = rotate
//           worldMapKitOverlay.Projection = WorldMapKitProjection.SphericalMercator;
//           wpfMap1.Overlays.Add(worldMapKitOverlay);
            

            
//            //radarImageLayer.Transparency = 99;

//            LayerOverlay layerOverlay = new LayerOverlay();
//            //layerOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("black"))));
////            layerOverlay.Layers.Add(worldLayer);
////            layerOverlay.Layers.Add(capitalLayer);
////            layerOverlay.Layers.Add(capitalLabelLayer);

////            var markerOverlay = new InMemoryMarkerOverlay();
//////
////            markerOverlay.ZoomLevelSet.ZoomLevel01.DefaultPointMarkerStyle.ImageSource = new BitmapImage(new Uri("/Resources/AQUA.png", UriKind.RelativeOrAbsolute));
////            markerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
////            var feature = new Feature(new Vertex(-94, 39)) {Id = "MyId"};
//                        var markerOverlay = new SimpleMarkerOverlay();
//            var rotationTransform = new RotateTransform(5);

//            var marker = new Marker(-94, 39)
//            {
//                ImageSource = null,
//                Content = ((char)40).ToString(),
//                FontSize = 14,
//                FontFamily = fontFam,
//                FontStyle = FontStyles.Normal,
//                //Foreground = Brushes.LimeGreen,
//                HorizontalContentAlignment = HorizontalAlignment.Left
//                // RenderTransform = rotationTransform
//            };

//            if (MapMarker != null)
//            {
                
//            }
            
//            markerOverlay.Markers.Add("Test", marker);
            
////            markerOverlay.FeatureSource.InternalFeatures.Clear();
////            markerOverlay.FeatureSource.InternalFeatures.Add("MyId", feature);
//            layerOverlay.Layers.Add(radarImageLayer);
//            layerOverlay.Layers.Add(shapeLayer);
//            //ExtentHelper.GetBoundingBoxOfItems()
//            rotate.Angle = -5.0;
//            shapeLayer.Open();
//            radarImageLayer.Open();

////
////            ScaleTransform scaleTranform = new ScaleTransform {ScaleY = -1};
////            wpfMap1.LayoutTransform = scaleTranform;

//           // wpfMap1.Overlays.Add(openStreetMapOverlay);
//            wpfMap1.Overlays.Add(layerOverlay);
//           // wpfMap1.Overlays.Add("Marker", markerOverlay);
//            //wpfMap1.MaximumScale = 300;
//            //wpfMap1.ZoomToScale(3.5, );
//            wpfMap1.CurrentExtentChanged += wpfMap1_CurrentExtentChanged;
//            wpfMap1.OverlaysDrawn += wpfMap1_OverlaysDrawn;
//            wpfMap1.MouseLeftButtonUp += WpfMap1OnMouseLeftButtonUp ;
//            //wpfMap1.
//            //wpfMap1.CenterAt(shapeLayer.FeatureSource.GetBoundingBox().GetCenterPoint());
//            wpfMap1.CurrentScaleChanged += wpfMap1_CurrentScaleChanged;
//            wpfMap1.CurrentExtent = radarImageLayer.GetBoundingBox(); //rotate.GetUpdatedExtent(shapeLayer.FeatureSource.GetBoundingBox()); //  //new RectanleShape(0, 78, 30, 26);
//            //wpfMap1.CurrentExtent = shapeLayer.FeatureSource.GetBoundingBox(); //
//            //wpfMap1.CurrentExtent = new RectangleShape(0, 78, 30, 26);
//            //wpfMap1.CurrentExtent = rotate.GetUpdatedExtent(wpfMap1.CurrentExtent);
            
//            //wpfMap1.ZoomIn(95);
//            wpfMap1.Refresh();
//        }

    }
}